import { Switch, Route, useRouteMatch } from 'react-router-dom';
import Spacings from '@commercetools-uikit/spacings';
import Welcome from './components/welcome';
import MyAccount from './components/my-account';
import PaymentMethods from './components/payment-methods';
import { myAccountUri, orderUri, paymentMethodsUri } from './constants';
import OrderList from './components/order-list';
import OrderDetails from './components/order-details';
import OrderProvider from './context/order';

const ApplicationRoutes = () => {
  const match = useRouteMatch();

  /**
   * When using routes, there is a good chance that you might want to
   * restrict the access to a certain route based on the user permissions.
   * You can evaluate user permissions using the `useIsAuthorized` hook.
   * For more information see https://docs.commercetools.com/custom-applications/development/permissions
   *
   * NOTE that by default the Custom Application implicitly checks for a "View" permission,
   * otherwise it won't render. Therefore, checking for "View" permissions here
   * is redundant and not strictly necessary.
   */

  return (
    <Spacings.Inset scale="l">
      <Switch>
        <Route path={`${match.path}/${myAccountUri}`} exact>
          <MyAccount />
        </Route>
        <Route path={`${match.path}/${paymentMethodsUri}`} exact>
          <PaymentMethods />
        </Route>
        <OrderProvider>
          <Route path={`${match.path}/${orderUri}`} exact>
            <OrderList />
          </Route>
          <Route path={`${match.path}/${orderUri}/:orderId`} exact>
            <OrderDetails />
          </Route>
        </OrderProvider>
        <Route>
          <Welcome />
        </Route>
      </Switch>
    </Spacings.Inset>
  );
};
ApplicationRoutes.displayName = 'ApplicationRoutes';

export default ApplicationRoutes;
